#!/bin/bash
# test script to apply filters to all files in a directory
# author: Rostislav Lán

# activate virtual environment when using this script
# this is necessary to run the script using the correct python and libraries versions
source .venv/bin/activate

#----------------------------Configuration------------------------------#

# place all image files to one folder
input_path=res/test/test-skript

# !!!!!!!!!!!!!!!!!!
# this is very important, run this on directories containing files with the same dpi
dpi=500
# !!!!!!!!!!!!!!!!!!

# recommend png, it's supported by opencv
format=jpg

# name of configuration file
config_file=conf/conf.json

# name of preset in conf. file
#presets=("strong" "test-weak" "test-repeat" "test-strong")
presets=("ridge" "weak")

# generate stl files and set generation mode {"planar", "curved", "mapped"}
generate_stl=true
generate_stl_mode="planar"

# in 1/10 of milimeters
height_line=2
height_base=3
curv_x=1.5
curv_y=4

#----------------------------Application---------------------------#

# function to apply filter to all files in directory
apply_filter() {
    for in in ${file_arr[@]}
    do
        # check that the file exists
        if test -f "$in"
        then
            # append preset name to filename for easier identification, if not generating stl (that would result in very long names)
            if $generate_stl; then
                out="${in%%${match1}*}${match1}$format"
            else
                out="${in%%${match1}*}_$preset${match1}$format"
            fi

            # skip stl files and files with preset name in them
            if [[ $in == *".stl"* ]] || [[ $in == *_* ]]; then
               ((j++))
               continue
            fi

            ((i++))
            echo -e "|\n|----------------------- File no. $i: $in ------------------------------|\n"

            if $generate_stl; then
                ((i++))
                if [[ "$generate_stl_mode" = "planar" ]]; then
                    python3 $exec_path $in $out $dpi -c $config_file $1 --stl p $height_line $height_base || break

                elif [[ "$generate_stl" = "curved" ]]; then
                    python3 $exec_path $in $out $dpi -c $config_file $1 --stl c $height_line $height_base $curv_x $curv_y || break

                elif [[ "$generate_stl" = "mapped" ]]; then
                    pass
                    python3 $exec_path $in $out $dpi -c $config_file $1 --stl m $height_line $height_base $fp_file|| break
                else
                    echo "Invalid stl generation mode"
                    break
                fi
            else
                python3 $exec_path $in $out $dpi -c $config_file $1 || break
            fi
        else 
            echo "File $file does not exist"
        fi
        
    done
}

# for pattern matching in filenames
exec_path=src/main.py
match1=.
match2=/
i=0
j=0
file_arr=()

# get all filenames in all subdirectories
for file in $input_path/*
do
    file_arr=("${file_arr[@]}" "$file")
done

# apply all given filter presets to all the discovered files
for preset in ${presets[@]}
do
    echo -e "\n|----------------------- Filter "$preset" ------------------------------|\n|"
    j=0
    apply_filter $preset $j
done

echo -e "\n|--------------------------- Done ----------------------------------|\n"
echo "Skipped $j files"
echo "Generated $i files"